SystemOrganization addCategory: #'Widgets-Core'!
SystemOrganization addCategory: #'Widgets-Sandbox'!
SystemOrganization addCategory: #'Widgets-Support'!
SystemOrganization addCategory: #'Widgets-Designer'!
SystemOrganization addCategory: #'Widgets-Custom'!
SystemOrganization addCategory: #'Widgets-Views'!
SystemOrganization addCategory: #'Widgets-Dialogs'!

!UiAbstractItemView methodsFor: 'signals' stamp: 'mt 10/14/2010 20:26:04.229'!
clicked: aModelIndex

	self emitAlways.! !

!UiAbstractItemView methodsFor: 'signals' stamp: 'mt 10/14/2010 20:26:08.87'!
doubleClicked: aModelIndex

	self emitAlways.! !

!UiAbstractItemView methodsFor: 'initialization' stamp: 'mt 10/14/2010 20:26:47.648'!
initialize

	"Initialize headers."
	verticalHeader := Morph new color: Color transparent; width: self scrollBarThickness; changeTableLayout; listDirection: #topToBottom.
	horizontalHeader := Morph new color: Color transparent; height: self scrollBarThickness; changeTableLayout; listDirection: #leftToRight.
	vHeaderScroller := TransformMorph new color: Color transparent.
	hHeaderScroller := TransformMorph new color: Color transparent.

	super initialize.
	
	self
		borderWidth: 0;
		color: Color white.
	
	"Initialize viewport."
	self scroller addMorph: self viewportClass new.
	self connect: self viewport signal: #focusChanged: toSelector: #scrollToShow:.
	self connect: self viewport signal: #clicked: toSelector: #clicked:.
	self connect: self viewport signal: #doubleClicked: toSelector: #doubleClicked:.
	self viewport verticalHeader: verticalHeader.
	self viewport horizontalHeader: horizontalHeader.
	
	"Initialize item delegates."
	itemDelegates := Dictionary new.
	self defaultItemDelegate: UiSimpleItemDelegate new.
	
	"Initialize headers - Finish."
	verticalHeader connect: self viewport signal: #resizedToWidth:height: toSelector: #height: pattern: #(2).
	vHeaderScroller addMorph: verticalHeader.

	horizontalHeader connect: self viewport signal: #resizedToWidth:height: toSelector: #width:.
	hHeaderScroller addMorph: horizontalHeader.! !

!UiAbstractItemView methodsFor: 'model access' stamp: 'mt 10/14/2010 21:02:31.888'!
reset
	self viewport clear.
	
	self fillViewportFor: nil animated: false.
	self resetHeaderItems.
	
	self updateLayout.! !

!UiSimpleItemDelegate methodsFor: 'layouting - private' stamp: 'mt 10/14/2010 20:21:52.074'!
doLayoutFor: aMorph

	| offset |
	self orientation = #horizontal ifTrue: [
		aMorph height: aMorph submorphs last height. "for smaller items use font height"
		
		"Manual layouting."
		offset := aMorph left + 3.
		aMorph submorphs do: [:m |
			m left: offset.
			offset := offset + m width + 2.
			m top: (aMorph top - (m height - aMorph height // 2))].
	
		"Expand item horizontally to its contents."
		aMorph
			width: aMorph submorphBounds width + 5; "font rendering bugfix"
			height: aMorph height + 1. "font rendering bugfix"
		
		^ self].
	
	self orientation = #vertical ifTrue: [
		aMorph width: aMorph submorphs last width + 10.
			
		"Manual layouting."
		offset := aMorph top + 3.
		aMorph submorphs do: [:m |
			m top: offset.
			offset := offset + m height + 2.
			m left: (aMorph left - (m width - aMorph width // 2))].
	
		aMorph height: aMorph submorphBounds height + 2].! !

!UiSimpleItemDelegate methodsFor: 'building' stamp: 'mt 10/14/2010 20:06:26.084'!
itemFor: aModelIndex

	| icon text item |
	icon := aModelIndex icon "ifNil: [Morph new extent: 16@16; color: Color transparent]".
	text := aModelIndex text.
	
	(text isNil and: [icon isNil]) ifTrue: [text := ' ' asText].
	
	item := Morph new color: Color transparent.
	
	icon ifNotNil: [item addMorphBack: icon asMorph].
	text ifNotNil: [
		text := text asText.
		item addMorphBack: text asMorph lock].
	
	"Store morphs in properties for later access."
	item
		setProperty: #text toValue: text;
		setProperty: #icon toValue: icon.

	self doLayoutFor: item.	

	^ item! !

Morph subclass: #UiIconPickerDialog
	instanceVariableNames: 'iconSetCombo iconView infoLabel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Widgets-Dialogs'!

!UiIconPickerDialog class methodsFor: 'as yet unclassified' stamp: 'mt 10/14/2010 20:34:30.931'!
open

	self new open.! !

!UiIconPickerDialog methodsFor: 'as yet unclassified' stamp: 'mt 10/14/2010 20:45:34.542'!
changeIconSet: anIndex

	iconView model iconSet: (UiIcons subclasses at: anIndex).! !

!UiIconPickerDialog methodsFor: 'as yet unclassified' stamp: 'mt 10/14/2010 20:47:24.871'!
chooseIcon: aModelIndex

	Clipboard clipboardText: (iconView model codeSnippetFor: aModelIndex).! !

!UiIconPickerDialog methodsFor: 'as yet unclassified' stamp: 'mt 10/14/2010 21:04:17.021'!
initialize

	super initialize.
	
	iconSetCombo := UiComboBox new hResizing: #spaceFill.
	UiIcons subclassesDo: [:s | iconSetCombo addText: s name].
	self connect: iconSetCombo signal: #currentIndexChanged:text: toSelector: #changeIconSet:.
	
	iconView := UiListIconView new
		listOrientation: #vertical;
		model: (UiIconModel new showText: false);
		hResizing: #spaceFill;
		vResizing: #spaceFill;
		borderStyle: (BorderStyle inset width: 1).
	self connect: iconView signal: #clicked: toSelector: #chooseIcon:.
	
	self
		color: (Color gray: 0.9);
		changeTableLayout;
		listDirection: #topToBottom;
		layoutInset: 5;
		cellInset: 5;
		cellPositioning: #topLeft.
		
	self
		addMorphBack: (UiLabel new text: 'Select an icon set then pick an icon below. The code to get
the form will be copied into the <b>clipboard</b>.' asHtmlText);
		addMorphBack: iconSetCombo;
		addMorphBack: iconView.
		
	"Initial set."
	self changeIconSet: iconSetCombo currentIndex.! !

!UiIconPickerDialog methodsFor: 'as yet unclassified' stamp: 'mt 10/14/2010 20:59:07.38'!
open

	| c |
	c := self color.
	(self openInWindowLabeled: 'Icon Picker')
		extent: 350@300.
		
	self color: c.! !

!UiSmalltalkModel methodsFor: 'initialization' stamp: 'mt 10/14/2010 19:36:09.409'!
initialize

	"SystemChangeNotifier uniqueInstance
		notify: self ofAllSystemChangesUsing: #processNotification:."! !

!UiListIconViewport methodsFor: 'initialization' stamp: 'mt 10/14/2010 20:57:45.903'!
initialize

	super initialize.
	maxItemExtent := 1@1.
	self orientation: #default.! !

!UiListIconViewport methodsFor: 'rows/columns - to model index' stamp: 'mt 10/14/2010 20:48:40.117'!
modelIndexFor: aCellIndex

	self orientation = #default
		ifTrue: [^ super modelIndexFor: aCellIndex].

	aCellIndex ifNil: [^ nil].
	
	^ (self orientation = #vertical
		ifTrue: [rows at: aCellIndex y - 1 * self maxItemsPerLine + aCellIndex x]
		ifFalse: [rows at: aCellIndex x - 1 * self maxItemsPerLine + aCellIndex y]) firstModelIndex! !

UiModel subclass: #UiListModel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Widgets-Custom'!

!UiListModel commentStamp: 'mt 10/14/2010 19:50:27.995' prior: 0!
A simple version of the generic model that only supports 1 column.!

UiListModel subclass: #UiIconModel
	instanceVariableNames: 'iconSet showText'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Widgets-Dialogs'!

!UiIconModel commentStamp: 'mt 10/14/2010 19:53:08.979' prior: 0!
Supports all subclasses of UiIcons as #iconSet.!

!UiIconModel methodsFor: 'accessing' stamp: 'mt 10/14/2010 20:38:17.087'!
codeSnippetFor: aModelIndex

	aModelIndex ifNil: [^ ''].
	
	^ self iconSet name, ' ', (self iconSelectors at: aModelIndex row)! !

!UiIconModel methodsFor: 'model data' stamp: 'mt 10/14/2010 19:49:44.229'!
iconAt: anIndex

	^ self iconSet perform: (self iconSelectors at: anIndex)! !

!UiIconModel methodsFor: 'accessing' stamp: 'mt 10/14/2010 20:36:36.757'!
iconSelectors

	self iconSet ifNil: [^ #()].
	^ self iconSet class organization listAtCategoryNamed: #accessing! !

!UiIconModel methodsFor: 'accessing' stamp: 'mt 10/14/2010 19:45:12.099'!
iconSet

	^ iconSet! !

!UiIconModel methodsFor: 'accessing' stamp: 'mt 10/14/2010 19:44:20.126'!
iconSet: anIconSet

	iconSet := anIconSet.
	self reset.! !

!UiIconModel methodsFor: 'counts' stamp: 'mt 10/14/2010 19:48:31.26'!
rowCount

	^ self iconSelectors size! !

!UiIconModel methodsFor: 'accessing' stamp: 'mt 10/14/2010 19:58:51.741'!
showText

	^ showText ifNil: [showText := true]! !

!UiIconModel methodsFor: 'accessing' stamp: 'mt 10/14/2010 19:58:43.53'!
showText: aBoolean

	showText := aBoolean.
	self reset.! !

!UiIconModel methodsFor: 'model data' stamp: 'mt 10/14/2010 19:59:09.323'!
textAt: anIndex

	^ self showText
		ifFalse: [nil]
		ifTrue: [(self iconSelectors at: anIndex) allButLast: 4 "remove icon suffix"]! !

!UiListModel methodsFor: 'counts' stamp: 'mt 10/14/2010 19:38:56.514'!
columnCountFor: aParentModelIndex

	^ 1! !

!UiListModel methodsFor: 'model data' stamp: 'mt 10/14/2010 19:47:02.848'!
iconAt: anRow

	self subclassResponsibility.! !

!UiListModel methodsFor: 'model data' stamp: 'mt 10/14/2010 19:46:47.469'!
iconFor: aModelIndex

	^ self iconAt: aModelIndex row! !

!UiListModel methodsFor: 'index generation' stamp: 'mt 10/14/2010 19:43:12.236'!
indexRow: aRowNumber column: aColumnNumber parent: aParentModelIndex

	^ (UiSimpleModelIndex row: aRowNumber column: aColumnNumber)
		model: self;
		parent: aParentModelIndex! !

!UiListModel methodsFor: 'counts' stamp: 'mt 10/14/2010 19:39:44.025'!
rowCount

	self subclassResponsibility.! !

!UiListModel methodsFor: 'counts' stamp: 'mt 10/14/2010 19:39:33.408'!
rowCountFor: aParentModelIndex

	^ self rowCount! !

!UiListModel methodsFor: 'model data' stamp: 'mt 10/14/2010 19:47:07.721'!
textAt: anRow

	self subclassResponsibility.! !

!UiListModel methodsFor: 'model data' stamp: 'mt 10/14/2010 19:46:33.425'!
textFor: aModelIndex

	^ self textAt: aModelIndex row! !

!UiViewColumnInfo methodsFor: 'geometry' stamp: 'mt 10/14/2010 20:17:06.246'!
optimalSize
	"Return the width of the largest item."
	
	| max |
	max := 0.
	items do: [:item | 
		item hResizing ~= #spaceFill
			ifTrue: [max := max max: (item width + (item valueOfProperty: #indent))]].
	max := max max: self headerItem submorphBounds width + 5. "font rendering bugfix"
	^ max! !

!UiComboBox methodsFor: 'adding' stamp: 'mt 10/14/2010 20:43:12.328'!
addText: aLabel

	listWidget addText: aLabel.
	
	listWidget items size = 1
		ifTrue: [self currentIndex: 1]! !

!UiComboBox methodsFor: 'accessing' stamp: 'mt 10/14/2010 20:42:53.745'!
currentIndex: anIndex

	listWidget currentRow: anIndex.
	self updateCurrentRow: anIndex.! !

!UiItemViewport methodsFor: 'event handling' stamp: 'mt 10/14/2010 20:46:30.445'!
click: evt

	self clicked: (self modelIndexFor: (self cellIndexFromPoint: evt position)).! !
