SystemOrganization addCategory: #'Widgets-Core'!
SystemOrganization addCategory: #'Widgets-Sandbox'!
SystemOrganization addCategory: #'Widgets-Support'!
SystemOrganization addCategory: #'Widgets-Designer'!
SystemOrganization addCategory: #'Widgets-Custom'!
SystemOrganization addCategory: #'Widgets-Views'!

!UiSimpleItemDelegate methodsFor: 'layouting - private' stamp: 'mt 10/14/2010 17:59:39.564'!
doLayoutFor: aMorph

	| offset |
	self orientation = #horizontal ifTrue: [
		aMorph height: aMorph submorphs last height. "for smaller items use font height"
		
		"Manual layouting."
		offset := aMorph left + 3.
		aMorph submorphs do: [:m |
			m left: offset.
			offset := offset + m width + 2.
			m top: (aMorph top - (m height - aMorph height // 2))].
	
		"Expand item horizontally to its contents."
		aMorph
			width: aMorph submorphBounds width + 10; "font rendering bugfix"
			height: aMorph height + 1. "font rendering bugfix"
		
		^ self].
	
	self orientation = #vertical ifTrue: [
		aMorph width: aMorph submorphs last width + 10.
			
		"Manual layouting."
		offset := aMorph top + 3.
		aMorph submorphs do: [:m |
			m top: offset.
			offset := offset + m height + 2.
			m left: (aMorph left - (m width - aMorph width // 2))].
	
		aMorph height: aMorph submorphBounds height + 2].! !

!UiSimpleItemDelegate methodsFor: 'building' stamp: 'mt 10/14/2010 17:43:36.69'!
itemFor: aModelIndex

	| icon text item textMorph |
	icon := aModelIndex icon "ifNil: [Morph new extent: 16@16; color: Color transparent]".
	text := (aModelIndex text ifNil: [' ']) asText.
	
	textMorph := text asMorph lock.
	
	item := Morph new color: Color transparent.
	
	icon ifNotNil: [item addMorphBack: icon asMorph].
	item addMorphBack: textMorph.
	
	"Store morphs in properties for later access."
	item
		setProperty: #text toValue: text;
		setProperty: #icon toValue: icon.

	self doLayoutFor: item.	

	^ item! !

!UiAbstractItemView methodsFor: 'initialization' stamp: 'mt 10/14/2010 15:44:04.082'!
initialize

	"Initialize headers."
	verticalHeader := Morph new color: Color transparent; width: self scrollBarThickness; changeTableLayout; listDirection: #topToBottom.
	horizontalHeader := Morph new color: Color transparent; height: self scrollBarThickness; changeTableLayout; listDirection: #leftToRight.
	vHeaderScroller := TransformMorph new color: Color transparent.
	hHeaderScroller := TransformMorph new color: Color transparent.

	super initialize.
	
	self
		borderWidth: 0;
		color: Color white.
	
	"Initialize viewport."
	self scroller addMorph: self viewportClass new.
	self connect: self viewport signal: #focusChanged: toSelector: #scrollToShow:.
	self viewport verticalHeader: verticalHeader.
	self viewport horizontalHeader: horizontalHeader.
	
	"Initialize item delegates."
	itemDelegates := Dictionary new.
	self defaultItemDelegate: UiSimpleItemDelegate new.
	
	"Initialize headers - Finish."
	verticalHeader connect: self viewport signal: #resizedToWidth:height: toSelector: #height: pattern: #(2).
	vHeaderScroller addMorph: verticalHeader.

	horizontalHeader connect: self viewport signal: #resizedToWidth:height: toSelector: #width:.
	hHeaderScroller addMorph: horizontalHeader.! !

!UiAbstractItemView methodsFor: 'model access' stamp: 'mt 10/14/2010 13:09:59.44'!
reset
	self viewport clear.
	
	self fillViewportFor: nil animated: false.
	self resetHeaderItems.
	
	self updateLayout.! !

!UiSmalltalkModel methodsFor: 'initialization' stamp: 'mt 10/13/2010 13:29:47.625'!
initialize

	SystemChangeNotifier uniqueInstance
		notify: self ofAllSystemChangesUsing: #processNotification:.! !

!UiListIconViewport methodsFor: 'initialization' stamp: 'mt 10/14/2010 17:19:17.313'!
initialize

	super initialize.
	self orientation: #default.! !

!UiListIconViewport methodsFor: 'rows/columns - to model index' stamp: 'mt 10/14/2010 17:25:43.136'!
modelIndexFor: aCellIndex

	self orientation = #default
		ifTrue: [^ super modelIndexFor: aCellIndex].

	aCellIndex ifNil: [^ nil].
	
	^ self orientation = #vertical
		ifTrue: [rows at: aCellIndex y - 1 * self maxItemsPerLine + aCellIndex x]
		ifFalse: [rows at: aCellIndex x - 1 * self maxItemsPerLine + aCellIndex y]! !

UiAbstractItemDelegate subclass: #UiIconicItemDelegate
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Widgets-Views'!

!UiIconicItemDelegate methodsFor: 'building' stamp: 'mt 10/14/2010 15:42:57.699'!
editorFor: aModelIndex

	^ nil "no editor"! !

!UiIconicItemDelegate methodsFor: 'building' stamp: 'mt 10/14/2010 16:02:22.489'!
itemFor: aModelIndex

	| icon text item offset textMorph |
	icon := aModelIndex icon "ifNil: [Morph new extent: 16@16; color: Color transparent]".
	text := (aModelIndex text ifNil: [' ']) asText.
	
	textMorph := text asMorph lock.
	
	item := Morph new
		color: Color transparent;
		width: textMorph width + 10. "for smaller items use font height"
	
	icon ifNotNil: [item addMorphBack: icon asMorph].
	item addMorphBack: textMorph.
	
	"Store morphs in properties for later access."
	item
		setProperty: #text toValue: text;
		setProperty: #icon toValue: icon.
	
	"Manual layouting."
	offset := item top + 3.
	item submorphs do: [:m |
		m top: offset.
		offset := offset + m height + 2.
		m left: (item left - (m width - item width // 2))].
	
	item height: item submorphBounds height + 2.
		
	^ item! !

!UiViewColumnInfo methodsFor: 'geometry' stamp: 'mt 10/11/2010 16:40:51.979'!
optimalSize
	"Return the width of the largest item."
	
	| max |
	max := 0.
	items do: [:item | 
		item hResizing ~= #spaceFill
			ifTrue: [max := max max: (item width + (item valueOfProperty: #indent))]].
	max := max max: self headerItem submorphBounds width + 10. "font rendering bugfix"
	^ max! !

!UiComboBox methodsFor: 'adding' stamp: 'mt 6/29/2010 17:14:20.93'!
addText: aLabel

	listWidget addText: aLabel.
	
	listWidget items size = 1
		ifTrue: [self updateCurrentRow: 1]! !

!UiComboBox methodsFor: 'accessing' stamp: 'mt 6/30/2010 08:19:25.106'!
currentIndex: anIndex

	listWidget currentRow: anIndex.! !

!UiItemViewport methodsFor: 'iterating' stamp: 'mt 10/14/2010 15:36:14.347'!
rowsCollect: aBlock

	^ rows collect: aBlock.! !
